@@ -3,7 +3,7 @@
 Class methods to be added to form fields such as django.forms.fields. These methods add additional
 error messages for AngularJS form validation.
 """
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy, ungettext_lazy
 
 
 def _input_required(field):
@@ -11,7 +11,7 @@ def _input_required(field):
     errors = []
     for key, msg in field.error_messages.items():
         if key == 'required':
-            errors.append(('required', msg))
+            errors.append(('$error.required', msg))
     return errors
 
 
@@ -22,16 +22,16 @@ def _min_max_length_errors(field):
     if hasattr(field, 'max_length') and field.max_length > 0:
         field.widget.attrs['ng-maxlength'] = field.max_length
     for item in field.validators:
-        if item.code == 'min_length':
+        if getattr(item, 'code', None) == 'min_length':
             message = ungettext_lazy(
                 'Ensure this value has at least %(limit_value)d character',
                 'Ensure this value has at least %(limit_value)d characters')
-            errors.append(('minlength', message % {'limit_value': field.min_length}))
-        if item.code == 'max_length':
+            errors.append(('$error.minlength', message % {'limit_value': field.min_length}))
+        if getattr(item, 'code', None) == 'max_length':
             message = ungettext_lazy(
                 'Ensure this value has at most %(limit_value)d character',
                 'Ensure this value has at most %(limit_value)d characters')
-            errors.append(('maxlength', message % {'limit_value': field.max_length}))
+            errors.append(('$error.maxlength', message % {'limit_value': field.max_length}))
     return errors
 
 
@@ -44,16 +44,18 @@ def _min_max_value_errors(field):
     errkeys = []
     for key, msg in field.error_messages.items():
         if key == 'min_value':
-            errors.append(('min', msg))
+            errors.append(('$error.min', msg))
             errkeys.append(key)
         if key == 'max_value':
-            errors.append(('max', msg))
+            errors.append(('$error.max', msg))
             errkeys.append(key)
     for item in field.validators:
-        if item.code not in errkeys and item.code == 'min_value':
-            errors.append(('min', item.message % {'limit_value': field.min_value}))
-        if item.code not in errkeys and item.code == 'max_value':
-            errors.append(('max', item.message % {'limit_value': field.max_value}))
+        if getattr(item, 'code', None) == 'min_value' and 'min_value' not in errkeys:
+            errors.append(('$error.min', item.message % {'limit_value': field.min_value}))
+            errkeys.append('min_value')
+        if getattr(item, 'code', None) == 'max_value' and 'max_value' not in errkeys:
+            errors.append(('$error.max', item.message % {'limit_value': field.max_value}))
+            errkeys.append('max_value')
     return errors
 
 
@@ -62,11 +64,13 @@ def _invalid_value_errors(field, ng_error_key):
     errkeys = []
     for key, msg in field.error_messages.items():
         if key == 'invalid':
-            errors.append((ng_error_key, msg))
+            errors.append(('$error.{0}'.format(ng_error_key), msg))
             errkeys.append(key)
     for item in field.validators:
-        if item.code not in errkeys and item.code == 'invalid':
-            errors.append((ng_error_key, item.message))
+        if getattr(item, 'code', None) == 'invalid' and 'invalid' not in errkeys:
+            errmsg = getattr(item, 'message', gettext_lazy('This input field does not contain valid data.'))
+            errors.append(('$error.{0}'.format(ng_error_key), errmsg))
+            errkeys.append('invalid')
     return errors
 
 
